@@ -11,17 +11,11 @@ use Getopt::Long qw<:config bundling>;
 use List::Util qw<first>;
 use Pod::Usage;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 my %opt;
 
 sub new {
     my ($package, %self) = @_;
-
-    $self{share_dir} = defined $ENV{GROK_SHAREDIR}
-        ? $ENV{GROK_SHAREDIR}
-        : dist_dir('grok')
-    ;
-
     return bless \%self, $package;
 }
 
@@ -44,16 +38,16 @@ sub run {
         print $file, "\n";
     }
     else {
-        my $output;
+        my $rendered;
         if ($opt{file}) {
-            $output = $self->render_file($opt{file}, $opt{output});
+            $rendered = $self->render_file($opt{file}, $opt{output});
         }
         else {
-            $output = $self->render_target($target, $opt{output});
+            $rendered = $self->render_target($target, $opt{output});
         }
 
-        die "Target '$target' not recognized\n" if !defined $output;
-        $self->_print($output);
+        die "Target '$target' not recognized\n" if !defined $rendered;
+        $self->_print($rendered, $opt{output});
     }
 
     return;
@@ -88,7 +82,7 @@ sub read_functions {
     return $self->{functions} if defined $self->{functions};
 
     my %functions;
-    my $S29_file = catfile($self->{share_dir}, 'Spec', 'S29-functions.pod');
+    my $S29_file = catfile(dist_dir('Perl6-Doc'), 'Synopsis', 'S29-functions.pod');
 
     ## no critic (InputOutput::RequireBriefOpen)
     open my $S29, '<', $S29_file or die "Can't open '$S29_file': $!";
@@ -137,23 +131,27 @@ sub read_functions {
 
 sub target_index {
     my ($self) = @_;
-    my $dir = catdir($self->{share_dir}, 'Spec');
+    
     my @index;
+    my %docs = map {
+        substr($_, 0, 1) => catdir(dist_dir('Perl6-Doc'), $_)
+    } qw<Apocalypse Exegesis Magazine Synopsis>;
 
-    # synopses
-    my @synopses = map { (splitpath($_))[2] } glob "$dir/*.pod";
-    s/\.pod$// for @synopses;
-    push @index, @synopses;
+    while (my ($type, $dir) = each %docs) {
+        my @parts = map { (splitpath($_))[2] } glob "$dir/*.pod";
+        s/\.pod$// for @parts;
+        push @index, @parts;
+    }
 
     # synopsis 32
-    my $S32_dir = catdir($dir, 'S32-setting-library');
+    my $S32_dir = catdir($docs{S}, 'S32-setting-library');
     my @sections = map { (splitpath($_))[2] } glob "$S32_dir/*.pod";
     s/\.pod$// for @sections;
     push @index, map { "S32-$_" } @sections;
 
     # functions from synopsis 29
     push @index, sort keys %{ $self->read_functions() };
-
+    
     return @index;
 }
 
@@ -164,7 +162,8 @@ sub detect_source {
     my $contents = do { local $/ = undef; scalar <$handle> };
     close $handle;
 
-    my ($first_pod) = $contents =~ /(^=(?!encoding)\S+)/m;
+    $contents =~ s/.*^=encoding\b.*$//m; # skip over =encoding
+    my ($first_pod) = $contents =~ /^(=\S+)/m;
     return if !defined $first_pod; # no Pod found
 
     if ($first_pod =~ /^=(?:pod|head\d+|over)$/
@@ -179,32 +178,36 @@ sub detect_source {
 sub find_target_file {
     my ($self, $arg) = @_;
 
-    my $target = $self->find_synopsis($arg);
+    my $target = $self->find_perl6_doc($arg);
     $target = $self->find_module_or_program($arg) if !defined $target;
 
     return if !defined $target;
     return $target;
 }
 
-sub find_synopsis {
-    my ($self, $syn) = @_;
-    my $dir = catdir($self->{share_dir}, 'Spec');
+sub find_perl6_doc {
+    my ($self, $doc) = @_;
+    
+    my %docs = map {
+        substr($_, 0, 1) => catdir(dist_dir('Perl6-Doc'), $_)
+    } qw<Apocalypse Exegesis Magazine Synopsis>;
 
-    if (my ($section) = $syn =~ /^S32-(\S+)$/i) {
-        my $S32_dir = catdir($dir, 'S32-setting-library');
+    # S32 is split up, need to special-case it
+    if (my ($section) = $doc =~ /^S32-(\S+)$/i) {
+        my $S32_dir = catdir($docs{S}, 'S32-setting-library');
         my @sections = map { (splitpath($_))[2] } glob "$S32_dir/*.pod";
-        my $found = first { /$section/i } @sections;
+        my $found = first { /^$section/i } @sections;
         
         if (defined $found) {
             return catfile($S32_dir, $found);
         }
     }
-    elsif ($syn =~ /^S\d+/i) {
-        my @synopses = map { (splitpath($_))[2] } glob "$dir/*.pod";
-        my $found = first { /\Q$syn/i } @synopses;
+    elsif (my ($type) = $doc =~ /^(\w)\d+/i) {
+        my @parts = map { (splitpath($_))[2] } glob "$docs{uc $type}/*.pod";
+        my $found = first { /\Q$doc/i } @parts;
         
         return if !defined $found;
-        return catfile($dir, $found);
+        return catfile($docs{uc $type}, $found);
     }
 
     return;
@@ -249,21 +252,26 @@ sub render_file {
 }
 
 sub _print {
-    my ($self, $output) = @_;
+    my ($self, $rendered, $output) = @_;
 
     if ($opt{no_pager} || !is_interactive()) {
-        print $output;
+        print $rendered;
     }
     else {
         my $pager = defined $ENV{PAGER} ? $ENV{PAGER} : $Config{pager};
+
+        my @args;
+        # tell less(1) to display colors without a fuss
+        push @args, '-f', '-R' if $pager =~ /less/ && $output eq 'ansi';
+
         my ($temp_fh, $temp) = tempfile(UNLINK => 1);
-        print $temp_fh $output;
+        print $temp_fh $rendered;
         close $temp_fh;
 
         # $pager might contain options (e.g. "more /e") so we pass a string
         $^O eq 'MSWin32'
-            ? system $pager . qq{ "$temp"}
-            : system $pager . qq{ '$temp'}
+            ? system $pager . qq{ @args "$temp"}
+            : system $pager . qq{ @args '$temp'}
         ;
     }
 
@@ -316,7 +324,7 @@ any Pod.
 Takes a valid C<grok> target as an argument. If found, it will return a path
 to a matching file, otherwise it returns nothing.
 
-=head2 C<find_synopsis>
+=head2 C<find_perl6_doc>
 
 Takes the name (or a substring of a name) of a Synopsis as an argument.
 Returns a path to a matching file if one is found, otherwise returns nothing.
