@@ -3,11 +3,11 @@ package App::Grok::Pod5;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 my %formatter = (
     text  => 'Pod::Text',
-    ansi  => 'Pod::Text::Color',
+    ansi  => 'Pod::Text::Ansi',
     xhtml => 'Pod::Xhtml',
     pod   => 'Pod::Perldoc::ToPod',
 );
